"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseRuntimeEngine = void 0;
const runtime_1 = require("./runtime");
const util_1 = require("./util");
const perf_hooks_1 = require("perf_hooks");
class BaseRuntimeEngine {
    constructor() {
        this.runtimeExtensions = [];
        this.contextExtensions = [];
        this.eventExtensions = [];
        this.healthExtensions = [];
    }
    add(extensionHandler) {
        extensionHandler(this);
    }
    addBaseRuntime(baseRuntime) {
        this.baseRuntime = baseRuntime;
    }
    addRuntimeExtension(ext) {
        //
        // This is for compatibility legacy layers
        // And this logic will be removed soon
        //
        const legacyExt = ext;
        if (legacyExt.beforeStart) {
            ext.beforeRuntimeStart = legacyExt.beforeStart;
        }
        if (legacyExt.beforeReady) {
            ext.afterFunctionStart = legacyExt.beforeReady;
        }
        this.runtimeExtensions.push(ext);
        return this;
    }
    addHealthExtension(healthExtensionHandler) {
        this.healthExtensions.push(healthExtensionHandler);
        return this;
    }
    addEventExtension(eventExtensionHandler) {
        this.eventExtensions.push(eventExtensionHandler);
        return this;
    }
    addContextExtension(contextExtensionHandler) {
        this.contextExtensions.push(contextExtensionHandler);
        return this;
    }
    async ready() {
        if (!this.baseRuntime) {
            this.addBaseRuntime(new runtime_1.ServerlessBaseRuntime());
        }
        this.runtime = util_1.completeAssign.apply(this, [this.baseRuntime].concat(this.runtimeExtensions));
        await this.getCurrentRuntime().init(this.contextExtensions);
        perf_hooks_1.performance.mark('midway-faas:runtimeStart:start');
        await this.getCurrentRuntime().runtimeStart(this.eventExtensions);
        perf_hooks_1.performance.mark('midway-faas:runtimeStart:end');
        perf_hooks_1.performance.mark('midway-faas:functionStart:start');
        await this.getCurrentRuntime().functionStart();
        perf_hooks_1.performance.mark('midway-faas:functionStart:end');
        this.measureMarksOnReady();
    }
    async close() {
        await this.runtime.close();
    }
    getCurrentRuntime() {
        return this.runtime;
    }
    measureMarksOnReady() {
        [
            'runtimeStart',
            'functionStart',
            'beforeRuntimeStartHandler',
            'afterRuntimeStartHandler',
            'beforeFunctionStartHandler',
            'afterFunctionStartHandler',
        ].forEach(it => {
            perf_hooks_1.performance.measure(`midway-faas:${it}:measure`, `midway-faas:${it}:start`, `midway-faas:${it}:end`);
        });
    }
}
exports.BaseRuntimeEngine = BaseRuntimeEngine;
//# sourceMappingURL=engine.js.map